aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMike Stump <mrs@wrs.com>2001-01-03 01:11:18 +0000
committerMike Stump <mrs@gcc.gnu.org>2001-01-03 01:11:18 +0000
commita412bf75d904604bc4cb05e888663ad70e4008cf (patch)
treefeb356f697d6b8e82dd34425a953c9378ea3d410
parent4890c2f43c55328b560ca99fb4a4058a68290cd9 (diff)
downloadgcc-a412bf75d904604bc4cb05e888663ad70e4008cf.zip
gcc-a412bf75d904604bc4cb05e888663ad70e4008cf.tar.gz
gcc-a412bf75d904604bc4cb05e888663ad70e4008cf.tar.bz2
* decl2.c: (max_tinst_depth): Increase to 50.
From-SVN: r38642
-rw-r--r--gcc/cp/ChangeLog4
-rw-r--r--gcc/cp/decl2.c17
2 files changed, 18 insertions, 3 deletions
diff --git a/gcc/cp/ChangeLog b/gcc/cp/ChangeLog
index ee542c8..f17a43b 100644
--- a/gcc/cp/ChangeLog
+++ b/gcc/cp/ChangeLog
@@ -1,3 +1,7 @@
+2000-12-22 Mike Stump <mrs@wrs.com>
+
+ * decl2.c: (max_tinst_depth): Increase to 50.
+
2001-01-02 Mark Mitchell <mark@codesourcery.com>
* class.c (invalidate_class_lookup_cache): Zero the
diff --git a/gcc/cp/decl2.c b/gcc/cp/decl2.c
index 2d14ab5..0b7ec3c 100644
--- a/gcc/cp/decl2.c
+++ b/gcc/cp/decl2.c
@@ -288,23 +288,29 @@ int warn_parentheses;
/* Non-zero means warn in function declared in derived class has the
same name as a virtual in the base class, but fails to match the
type signature of any virtual function in the base class. */
+
int warn_overloaded_virtual;
/* Non-zero means warn when declaring a class that has a non virtual
destructor, when it really ought to have a virtual one. */
+
int warn_nonvdtor;
/* Non-zero means warn when a function is declared extern and later inline. */
+
int warn_extern_inline;
/* Non-zero means warn when the compiler will reorder code. */
+
int warn_reorder;
/* Non-zero means warn when synthesis behavior differs from Cfront's. */
+
int warn_synth;
/* Non-zero means warn when we convert a pointer to member function
into a pointer to (void or function). */
+
int warn_pmf2ptr = 1;
/* Nonzero means warn about violation of some Effective C++ style rules. */
@@ -370,10 +376,12 @@ int flag_default_inline = 1;
/* Controls whether compiler generates 'type descriptor' that give
run-time type information. */
+
int flag_rtti = 1;
/* Nonzero if we wish to output cross-referencing information
for the GNU class browser. */
+
extern int flag_gnu_xref;
/* Nonzero if we want to support huge (> 2^(sizeof(short)*8-1) bytes)
@@ -434,10 +442,11 @@ int flag_honor_std = ENABLE_STD_NAMESPACE;
int flag_inline_trees = 0;
-/* Maximum template instantiation depth. Must be at least 17 for ISO
- compliance. */
+/* Maximum template instantiation depth. This limit is rather
+ arbitrary, but it exists to limit the time it takes to notice
+ infinite template instantiations. */
-int max_tinst_depth = 17;
+int max_tinst_depth = 50;
/* The name-mangling scheme to use. Must be 1 or greater to support
template functions with identical types, but different template
@@ -446,11 +455,13 @@ int name_mangling_version = 2;
/* Nonzero if wchar_t should be `unsigned short' instead of whatever it
would normally be, for use with WINE. */
+
int flag_short_wchar;
/* Nonzero if squashed mangling is to be performed.
This uses the B and K codes to reference previously seen class types
and class qualifiers. */
+
int flag_do_squangling;
/* Nonzero means output .vtable_{entry,inherit} for use in doing vtable gc. */